*Raj 1-31-08
*This file constructs Tables 3 and 4
*Dataset prepared by dataprep.do 

clear
cap log close
set more off
set mem 300m
set matsize 500


***PART 1 Basic setup

*Sample selection in pooled data
use ../pooled_data
keep if age<65
keep if male==1

*Drop all recalls (recall==1 and recall==2)
keep if recall==0

*Drop all obs with missing data
keep if sevpay_yn~=.&tenure_yrs~=.&hh_netliq_pred~=.

*Censor at 50 weeks
replace censored_survey = 1 if dur_survey>50&dur_survey<.
replace dur_survey=50 if dur_survey>50&dur_survey<.

*Choose duration measure: Survey data
global Z = "final"
drop if dur_survey==.|dur_survey==0
gen censored=censored_survey
gen dur = dur_survey
stset dur [pweight=weight], failure(censored==0)

gen preind_1dig = int(preind_2dig/10)
gen preocc_1dig = int(preocc_2dig/10)

mkspline tenure_spl 10 = tenure, pct
gen l_annwg = log(preui_wageinc)
gen l_wba = log(wba)
mkspline l_annwg_spl 10 = l_annwg, pct

*Split data by predicted asset holdings
xtile netliq_q = hh_netliq_pred, nq(2)
#delimit;
foreach num of numlist 1/2 {;
   gen int_netliq`num'sevpay = (netliq_q==`num')*sevpay_yn if netliq_q~=.;
};
foreach x of numlist 1/2 {;
   foreach y of numlist 1/10 {;
   gen netliq`x'_wg`y' = (netliq_q==`x')*l_annwg_spl`y' if netliq_q~=.;
   };
};

sum tenure_yrs [w=weight] if sevpay_yn==1, d;
*Split data by tenure -- above/below median among sevpay recipients (median: 4.952);
gen ten_q = 1 if tenure_yrs<4.832;
replace ten_q = 2 if tenure_yrs>=4.832;
#delimit;
foreach num of numlist 1/2 {;
   gen int_ten`num'sevpay = (ten_q==`num')*sevpay_yn if ten_q~=.;
};
foreach x of numlist 1/2 {;
   foreach y of numlist 1/10 {;
   gen ten`x'_wg`y' = (ten_q==`x')*l_annwg_spl`y' if ten_q~=.;
   };
};

#delimit cr

***2 Summary statistics

log using summary_stats_sevpay, smcl replace
set more off

gen reprate = 52*wba/preui_wageinc

*3 columns: Pooled, sevpay_yn == 1, and sevpay_yn == 0

*Pooled sample
sum dur_survey dur_admin wba reprate preui_wageinc dropout collgr age married tenure_yrs [w=weight]
gen temp=1
table temp [pweight=weight], c(median dur_survey median dur_admin median preui_wageinc median tenure_yrs)
drop temp

*Results by sevpay status
sum sevpay_yn [w=weight]
sum dur_survey dur_admin wba reprate preui_wageinc dropout collgr age married tenure_yrs [w=weight] if sevpay_yn==0
sum dur_survey dur_admin wba reprate preui_wageinc dropout collgr age married tenure_yrs [w=weight] if sevpay_yn==1

table sevpay_yn [pweight=weight], c(median dur_survey median dur_admin median preui_wageinc median tenure_yrs)

*Sample sizes
count
count if sevpay_yn==0
count if sevpay_yn==1

gen tencap = min(tenure_yrs,26)
bys ten_q: sum(tencap) [w=weight] if sevpay_yn==1
sum(tencap) [w=weight] if sevpay_yn==1

log close

***3 Survival graphs

global xlimit = 21

*Fig 5 Survival graphs by sevpay receipt status
egen mean_tenure = mean(tenure_yrs)
gen tenure_demean = tenure_yrs-mean_tenure

sts gen surv_fn = s if netliq_q~=., strata(sevpay_yn) adjustfor(tenure_demean)

*adjustfor _Ipre*

bys dur sevpay_yn: gen index=_n
#delimit;
twoway scatter surv_fn dur if sevpay_yn==0&index==1&dur<$xlimit, c(l) msize(vsmall) clcolor(navy) clstyle(solid) mfcolor(navy) mlcolor(navy) clcolor(navy)  || 
scatter surv_fn dur if sevpay_yn==1&index==1&dur<$xlimit, c(l) clcolor(red) msymbol(none) 
legend(label(1 "No Severance") label(2 "Received Severance") rows(1))
xtitle("Weeks Unemployed") ytitle("Fraction Unemployed")  ylabel(#5, grid) ymtick(##2, grid) xmtick(##2, grid)
title(Figure 5) subtitle("Effect of Severance Pay on Durations") graphregion(fcolor(white));
#delimit cr
graph save g1_$Z, asis replace

*Fig 6a-b Breakdown by predicted assets of survival graphs by sevpay receipt status
cap drop surv_fn_q1
sts gen surv_fn_q = s, strata(sevpay_yn netliq_q) adjustfor(tenure_demean), if netliq_q~=.
cap drop index
bys dur sevpay_yn netliq_q: gen index=_n

#delimit;
twoway scatter surv_fn_q dur if sevpay_yn==0&index==1&dur<$xlimit&netliq_q==1, c(l) msize(vsmall) clcolor(navy) clstyle(solid) mfcolor(navy) mlcolor(navy) clcolor(navy)  || 
scatter surv_fn_q dur if sevpay_yn==1&index==1&dur<$xlimit&netliq_q==1, c(l) clcolor(red) msymbol(none) 
legend(label(1 "No Severance") label(2 "Received Severance") rows(1))
xtitle("Weeks Unemployed") ytitle("Fraction Unemployed")  ylabel(#5, grid) ymtick(##2, grid) xmtick(##2, grid)
title(Figure 6a) subtitle("Effect of Severance Pay on Durations: Below Median Net Wealth") graphregion(fcolor(white));
#delimit cr
graph save g2_$Z, asis replace

#delimit;
twoway scatter surv_fn_q dur if sevpay_yn==0&index==1&dur<$xlimit&netliq_q==2, c(l) msize(vsmall) clcolor(navy) clstyle(solid) mfcolor(navy) mlcolor(navy) clcolor(navy)  || 
scatter surv_fn_q dur if sevpay_yn==1&index==1&dur<$xlimit&netliq_q==2, c(l) clcolor(red) msymbol(none) 
legend(label(1 "No Severance") label(2 "Received Severance") rows(1))
xtitle("Weeks Unemployed") ytitle("Fraction Unemployed")  ylabel(#5, grid) ymtick(##2, grid) xmtick(##2, grid)
title(Figure 6b) subtitle("Effect of Severance Pay on Durations: Above Median Net Wealth") graphregion(fcolor(white));
#delimit cr
graph save g3_$Z, asis replace

log using survival_curves_sevpay, smcl replace
sts list if netliq_q~=., strata(sevpay_yn) adjustfor(tenure_demean) compare at(1(1)50)
sts list if netliq_q~=., strata(netliq_q sevpay_yn) adjustfor(tenure_demean) compare at(1(1)50)
log close


***4 Parametric estimates.

log using param_results_sevpay, smcl replace

set more off

*3.1 no controls except tenure
stcox sevpay_yn tenure_yrs, cluster(st) nohr tvc(sevpay_yn)
*3.2 full controls
xi i.st i.preind_1 i.preocc_1 
stcox sevpay_yn age married dropout collgr l_annwg_spl* tenure_spl* _I* l_wba, cluster(st) nohr tvc(sevpay_yn)

*Split into high/low asset; note that this has no sevpay-tvc-netliq_q interaction for precision gain
*3.3 netliq_q breakdown, with only tenure control
stcox int_netliq1sevpay int_netliq2sevpay tenure_yrs, nohr strata(netliq_q) tvc(sevpay_yn) cluster(st)
test int_netliq1sevpay=int_netliq2sevpay
*3.4 netliq_q breakdown, with full controls
xi i.st i.preind_1*i.netliq_q i.preocc_1*i.netliq_q
stcox int_netliq1sevpay int_netliq2sevpay age married dropout collgr netliq*wg* tenure_spl* _I* l_wba, nohr strata(netliq_q) tvc(sevpay_yn) cluster(st)
test int_netliq1sevpay=int_netliq2sevpay

*3.5
stcox int_ten1sevpay int_ten2sevpay tenure_yrs, nohr strata(ten_q) tvc(sevpay_yn) cluster(st)
test int_ten1sevpay=int_ten2sevpay
*3.6 ten_q breakdown, with full controls
xi i.st i.preind_1*i.ten_q i.preocc_1*i.ten_q
stcox int_ten1sevpay int_ten2sevpay age married dropout collgr ten*wg* tenure_spl* _I* l_wba, nohr strata(ten_q) tvc(sevpay_yn) cluster(st)
test int_ten1sevpay=int_ten2sevpay

log close
